@@ -8,7 +8,7 @@
 Constants used in the Hummingbird converters are defined here.
 """
 
-ALPHA = "alpha"
+BASE_PREDICTION = "base_prediction"
 """Alpha"""
 
 LEARNING_RATE = "learning_rate"
@@ -22,3 +22,12 @@ REORDER_TREES = "reorder_trees"
 
 ONNX_INPUTS = "onnx_inputs"
 """The inputs to the onnx model"""
+
+ONNX_TEST_INPUT = "onnx_test_input"
+"""The test input data for the onnx model"""
+
+OFFSET = "offset_"
+"""offset of the sklearn anomaly detection implementation"""
+
+MAX_SAMPLES = "max_samples_"
+"""max_samples of sklearn isolation forest implementation"""
