@@ -20,25 +20,36 @@ GradientBoostingClassifier,
 GradientBoostingRegressor,
 HistGradientBoostingClassifier,
 HistGradientBoostingRegressor,
+IsolationForest,
 LinearRegression,
 LinearSVC,
 LogisticRegression,
 LogisticRegressionCV,
+MaxAbsScaler,
+MinMaxScaler,
 Normalizer,
+OneHotEncoder,
 RandomForestClassifier,
 RandomForestRegressor,
+RobustScaler,
+SelectKBest,
+SGDClassifier,
+StandardScaler,
 TreeEnsembleClassifier,
 TreeEnsembleRegressor,
-SGDClassifier,
+VarianceThreshold,
 
 LGBMClassifier,
+LGBMRanker,
 LGBMRegressor,
 
+
 XGBClassifier,
+XGBRanker,
 XGBRegressor
 """
 from .exceptions import MissingConverter
-from ._utils import torch_installed, sklearn_installed, lightgbm_installed, xgboost_installed, onnx_installed
+from ._utils import torch_installed, sklearn_installed, lightgbm_installed, xgboost_installed, onnx_runtime_installed
 
 
 def _build_sklearn_operator_list():
@@ -57,6 +68,7 @@ def _build_sklearn_operator_list():
             GradientBoostingRegressor,
             HistGradientBoostingClassifier,
             HistGradientBoostingRegressor,
+            IsolationForest,
             RandomForestClassifier,
             RandomForestRegressor,
         )
@@ -75,7 +87,10 @@ def _build_sklearn_operator_list():
         from sklearn.svm import LinearSVC, SVC, NuSVC
 
         # Preprocessing
-        from sklearn.preprocessing import Normalizer
+        from sklearn.preprocessing import MaxAbsScaler, MinMaxScaler, Normalizer, OneHotEncoder, RobustScaler, StandardScaler
+
+        # Features
+        from sklearn.feature_selection import SelectKBest, VarianceThreshold
 
         return [
             # Trees
@@ -87,6 +102,8 @@ def _build_sklearn_operator_list():
             GradientBoostingRegressor,
             HistGradientBoostingClassifier,
             HistGradientBoostingRegressor,
+            IsolationForest,
+            OneHotEncoder,
             RandomForestClassifier,
             RandomForestRegressor,
             # Linear-methods
@@ -99,7 +116,14 @@ def _build_sklearn_operator_list():
             NuSVC,
             SVC,
             # Preprocessing
+            MaxAbsScaler,
+            MinMaxScaler,
             Normalizer,
+            RobustScaler,
+            StandardScaler,
+            # Feature selection
+            SelectKBest,
+            VarianceThreshold,
         ]
 
     return []
@@ -110,9 +134,9 @@ def _build_xgboost_operator_list():
     List all suported XGBoost (Sklearn API) operators.
     """
     if xgboost_installed():
-        from xgboost import XGBClassifier, XGBRegressor
+        from xgboost import XGBClassifier, XGBRanker, XGBRegressor
 
-        return [XGBClassifier, XGBRegressor]
+        return [XGBClassifier, XGBRanker, XGBRegressor]
 
     return []
 
@@ -122,9 +146,9 @@ def _build_lightgbm_operator_list():
     List all suported LightGBM (Sklearn API) operators.
     """
     if lightgbm_installed():
-        from lightgbm import LGBMClassifier, LGBMRegressor
+        from lightgbm import LGBMClassifier, LGBMRanker, LGBMRegressor
 
-        return [LGBMClassifier, LGBMRegressor]
+        return [LGBMClassifier, LGBMRanker, LGBMRegressor]
 
     return []
 
@@ -134,9 +158,17 @@ def _build_onnxml_operator_list():
     """
     List all suported ONNXML operators.
     """
-    if onnx_installed():
+    if onnx_runtime_installed():
         return [
-            # Tree-based models.
+            # Linear-based models
+            "LinearClassifier",
+            "LinearRegressor",
+            # ONNX operators.
+            "Cast",
+            # Preprocessing
+            "Normalizer",
+            "Scaler",
+            # Tree-based models
             "TreeEnsembleClassifier",
             "TreeEnsembleRegressor",
         ]
@@ -155,7 +187,7 @@ def _build_backend_map():
         backends.add(torch.__name__)
         backends.add("py" + torch.__name__)  # For compatibility with earlier versions.
 
-    if onnx_installed():
+    if onnx_runtime_installed():
         import onnx
 
         backends.add(onnx.__name__)
@@ -238,11 +270,5 @@ ONNX_OUTPUT_MODEL_NAME = "onnx_model_name"
 ONNX_INITIAL_TYPES = "onnx_initial_types"
 """For ONNX models we can explicitly set the input types and shapes."""
 
-ONNX_INPUT_NAMES = "onnx_input_names"
-"""For ONNX models we can explicitly select the input columns to use."""
-
-ONNX_OUTPUT_NAMES = "onnx_output_names"
-"""For ONNX models we can explicitly select the output columns to return."""
-
 ONNX_TARGET_OPSET = "onnx_target_opset"
 """For ONNX models we can set the target opset to use. 9 by default."""
